pub enum BackupError {
DataTooLarge,
DataSizeInvalid,
}Expand description
Errors for user data backup procedures
Variants
DataTooLarge
Emitted when user data is larger than backup registers capacity
DataSizeInvalid
Emitted when user data size is not divisible by 4 bytes