CLINT

Struct CLINT 

pub struct CLINT;
CLINT peripheral

Implementations

Source

impl CLINT

pub fn is_interrupting() -> bool

Returns true if a machine timer OR software interrupt is pending.

pub fn is_enabled() -> bool

Returns true if machine timer OR software interrupts are enabled.

pub unsafe fn enable()

Enables machine timer AND software interrupts to allow the CLINT to trigger interrupts.

Safety

Enabling the CLINT may break mask-based critical sections.

pub fn disable()

Disables machine timer AND software interrupts to prevent the CLINT from triggering interrupts.

pub fn mswi_is_interrupting() -> bool

Returns true if a machine software interrupt is pending.

pub fn mswi_is_enabled() -> bool

Returns true if Machine Software Interrupts are enabled.

pub unsafe fn mswi_enable()

Enables the MSWI peripheral.

Safety

Enabling the MSWI may break mask-based critical sections.

pub fn mswi_disable()

Disables the MSWI peripheral.

pub const fn mswi() -> MSWI

Returns the MSWI peripheral.

pub fn mtimer_is_interrupting() -> bool

Returns true if a machine timer interrupt is pending.

pub fn mtimer_is_enabled() -> bool

Returns true if Machine Timer Interrupts are enabled.

pub unsafe fn mtimer_enable()

Sets the Machine Timer Interrupt bit of the mie CSR. This bit must be set for the MTIMER to trigger machine timer interrupts.

Safety

Enabling the MTIMER may break mask-based critical sections.

pub fn mtimer_disable()

Clears the Machine Timer Interrupt bit of the mie CSR. When cleared, the MTIMER cannot trigger machine timer interrupts.

pub const fn mtimer() -> MTIMER

Returns the MTIMER peripheral.

pub const fn mtime() -> MTIME

Returns the MTIME register of the MTIMER peripheral.

Source

impl CLINT

pub const fn freq() -> usize

Returns the frequency of the MTIME register.

pub const fn delay() -> Delay

Delay implementation for CLINT peripherals.

Note

You must export the [embedded_hal::delay::DelayNs] trait in order to use delay methods.

Source

impl CLINT

pub fn mtimecmp0() -> MTIMECMP

Returns the mtimecmp register for HART 0 .

Source

impl CLINT

pub fn msip0() -> MSIP

Returns the msip register for HART 0 .